/* $Id: isaac_dfs.h,v 1.40 2013-03-12 08:06:48 llundin Exp $
 *
 * This file is part of the ISAAC Pipeline
 * Copyright (C) 2002,2003 European Southern Observatory
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02111-1307  USA
 */

/*
 * $Author: llundin $
 * $Date: 2013-03-12 08:06:48 $
 * $Revision: 1.40 $
 * $Name: not supported by cvs2svn $
 */

#ifndef ISAAC_DFS_H
#define ISAAC_DFS_H

/*-----------------------------------------------------------------------------
   								Define
 -----------------------------------------------------------------------------*/

/* Column names */
#define ISAAC_COL_WAVELENGTH                "Wavelength"
#define ISAAC_COL_EMISSION                  "Emission"

/* Define here the PRO.CATG keywords */
#define ISAAC_IMG_DARK_AVG                  "MASTER_DARK"
#define ISAAC_IMG_TWFLAT_RES                "MASTER_IMG_FLAT"
#define ISAAC_IMG_TWFLAT_BPM                "MASTER_BPM"
#define ISAAC_IMG_TWFLAT_INTERC             "MASTER_IMG_FLAT_INTERC"
#define ISAAC_IMG_TWFLAT_ERR                "MASTER_IMG_FLAT_ERRMAP"
#define ISAAC_IMG_SLITPOS_RES               "SLIT_DESC"
#define ISAAC_IMG_ILLUM_RES                 "ILLUM_FRAME"
#define ISAAC_IMG_ILLUM_TAB                 "ILLUM_FLUX"
#define ISAAC_IMG_DETLIN_A                  "DETLIN_A"
#define ISAAC_IMG_DETLIN_B                  "DETLIN_B"
#define ISAAC_IMG_DETLIN_C                  "DETLIN_C"
#define ISAAC_IMG_DETLIN_Q                  "DETLIN_Q"
#define ISAAC_IMG_JITTER_COMB               "COADDED_IMG"
#define ISAAC_IMG_JITTER_STARS              "STARS_TAB"
#define ISAAC_IMG_JITTER_BG                 "SKY_TAB"
#define ISAAC_IMG_ZPOINT_TAB                "ZP_TAB"
#define ISAAC_IMG_ZPOINT_CHECK              "ZPOINT"
#define ISAAC_SPC_FLAT_SW_RES               "MASTER_SP_FLAT"
#define ISAAC_SPC_FLAT_LW_RES               "LW_MASTER_SP_FLAT"
#define ISAAC_SPC_ARC_SW_RES                "ARC_COEF"
#define ISAAC_SPC_ARC_LW_RES                "LW_ARC_COEF"
#define ISAAC_SPC_ARC_SW_CORR               "ARC_CORRECT"
#define ISAAC_SPC_ARC_LW_CORR               "LW_ARC_CORRECT"
#define ISAAC_SPC_STARTRACE_SW_RES          "STAR_TRACE_COEF"
#define ISAAC_SPC_STARTRACE_LW_RES          "LW_STAR_TRACE_COEF"
#define ISAAC_SPC_STARTRACE_SW_POS          "STAR_TRACE_POSI"
#define ISAAC_SPC_STARTRACE_LW_POS          "LW_STAR_TRACE_POSI"
#define ISAAC_SPC_STARTRACE_SW_SHAPE        "STAR_TRACE_SHAPE"
#define ISAAC_SPC_STARTRACE_LW_SHAPE        "LW_STAR_TRACE_SHAPE"
#define ISAAC_SPC_JITTER_COMB               "OBS_COMBINED"
#define ISAAC_SPC_JITTER_EXTR               "OBS_EXTRACTED"
#define ISAAC_SPC_JITTER_COMB_STD           "SPECTRA_COMBINED"
#define ISAAC_SPC_JITTER_EXTR_STD           "SPEC_EXTRACTED"
#define ISAAC_SPC_WLCALIB_RES               "WLCALIB"
#define ISAAC_UTIL_SEDS_RES                 "SEDS"
#define ISAAC_UTIL_STDSTARS_RES             "STDSTARS_CATS"
#define ISAAC_UTIL_GENLINES_OH_CAT          "CALPRO_OH_CATALOG"
#define ISAAC_UTIL_GENLINES_XE_CAT          "CALPRO_XE_CATALOG"
#define ISAAC_UTIL_GENLINES_AR_CAT          "CALPRO_AR_CATALOG"

/* Define here the DO.CATG keywords */
#define ISAAC_CALPRO_OH_CAT                 "CALPRO_OH_CATALOG"
#define ISAAC_CALPRO_XE_CAT                 "CALPRO_XE_CATALOG"
#define ISAAC_CALPRO_AR_CAT                 "CALPRO_AR_CATALOG"
#define ISAAC_CALIB_SED                     "SEDS"
#define ISAAC_CALIB_STDSTARS                "STDSTARS_CATS"
#define ISAAC_CALIB_FLAT                    "MASTER_IMG_FLAT"
#define ISAAC_CALIB_BPM                     "MASTER_BPM"
#define ISAAC_CALIB_DARK                    "MASTER_DARK"
#define ISAAC_CALIB_DETLIN_A                "DETLIN_A"
#define ISAAC_CALIB_DETLIN_B                "DETLIN_B"
#define ISAAC_CALIB_DETLIN_C                "DETLIN_C"
#define ISAAC_CALIB_SPFLAT                  "MASTER_SP_FLAT"
#define ISAAC_CALIB_LW_SPFLAT               "LW_MASTER_SP_FLAT"
#define ISAAC_CALIB_ARC                     "ARC_COEF"
#define ISAAC_CALIB_LW_ARC                  "LW_ARC_COEF"
#define ISAAC_CALIB_STARTRACE               "STAR_TRACE_COEF"
#define ISAAC_CALIB_LW_STARTRACE            "LW_STAR_TRACE_COEF"

#define ISAAC_ACQUISITION                   "IM_ACQ"
#define ISAAC_TEST                          "TEST_FRAME"
#define ISAAC_IMG_ILLUM_RAW                 "IM_ILLUM"
#define ISAAC_IMG_DETLIN_LAMP_RAW           "LINEAR_LAMP"
#define ISAAC_IMG_DETLIN_DARK_RAW           "LINEAR_DARK"
#define ISAAC_IMG_SLITPOS_RAW               "SLIT_IMG"
#define ISAAC_IMG_SLITPOS_CAL_RAW           "SLIT_IMG_CAL"
#define ISAAC_IMG_ZPOINT_RAW                "IM_ZPOINT"
#define ISAAC_IMG_ZPOINT_CHOPPING_RAW       "IM_CHOPPING_CAL"
#define ISAAC_IMG_TWFLAT_POL_RAW            "POL_FLAT"
#define ISAAC_IMG_TWFLAT_RAW                "IM_FLAT"
#define ISAAC_IMG_DARK_RAW                  "IM_DARK"
#define ISAAC_SPC_ARC_RAW                   "SP_ARC"
#define ISAAC_SPC_FLAT_RAW                  "SP_FLAT"
#define ISAAC_SPC_STARTRACE_IM_RAW          "IM_STARTRACE"
#define ISAAC_SPC_STARTRACE_SP_RAW          "SP_STARTRACE"
#define ISAAC_SPC_JITTER_CHOP_RAW           "SP_CHOPPING"
#define ISAAC_SPC_JITTER_CHOP_CAL_RAW       "SP_CHOPPING_CAL"
#define ISAAC_SPC_JITTER_NODOBJ_RAW         "SP_NODDINGOBJ"
#define ISAAC_SPC_JITTER_NODSKY_RAW         "SP_NODDINGSKY"
#define ISAAC_SPC_RESPFUNC_RAW              "SP_NODDING_CAL"
#define ISAAC_SPC_RESPFUNC_OBJ_RAW          "SP_NODDING_CALOBJ"
#define ISAAC_SPC_RESPFUNC_SKY_RAW          "SP_NODDING_CALSKY"
#define ISAAC_SPC_RESPFUNC_FLUX_RAW         "SP_NODDING_FLUX"
#define ISAAC_IMG_JITTER_OBJ_RAW            "IM_JITTEROBJ"
#define ISAAC_IMG_JITTER_SKY_RAW            "IM_JITTERSKY"
#define ISAAC_IMG_JITTER_CHOP_RAW           "IM_CHOPPING"
#define ISAAC_UTIL_SEDS_RAW                 "SED"
#define ISAAC_UTIL_STDSTARS_RAW             "STDSTAR_CAT"
#define ISAAC_UTIL_GENLINES_RAW             "CATALOG"

/*-----------------------------------------------------------------------------
                                Functions prototypes
 -----------------------------------------------------------------------------*/

int isaac_dfs_set_groups(cpl_frameset *) ;

#endif
